Added hipMemset3D
Bu işleme şunda yer alıyor:
@@ -1450,6 +1450,27 @@ hipError_t hipMemset2D(void* dst, size_t pitch, int value, size_t width, size_t
|
||||
|
||||
hipError_t hipMemset2DAsync(void* dst, size_t pitch, int value, size_t width, size_t height,hipStream_t stream __dparm(0));
|
||||
|
||||
/**
|
||||
* @brief Fills synchronously the memory area pointed to by pitchedDevPtr with the constant value.
|
||||
*
|
||||
* @param[in] pitchedDevPtr
|
||||
* @param[in] value - constant value to be set
|
||||
* @param[in] extent
|
||||
* @return #hipSuccess, #hipErrorInvalidValue, #hipErrorMemoryFree
|
||||
*/
|
||||
hipError_t hipMemset3D(hipPitchedPtr pitchedDevPtr, int value, hipExtent extent );
|
||||
|
||||
/**
|
||||
* @brief Fills asynchronously the memory area pointed to by pitchedDevPtr with the constant value.
|
||||
*
|
||||
* @param[in] pitchedDevPtr
|
||||
* @param[in] value - constant value to be set
|
||||
* @param[in] extent
|
||||
* @param[in] stream
|
||||
* @return #hipSuccess, #hipErrorInvalidValue, #hipErrorMemoryFree
|
||||
*/
|
||||
hipError_t hipMemset3DAsync(hipPitchedPtr pitchedDevPtr, int value, hipExtent extent ,hipStream_t stream __dparm(0));
|
||||
|
||||
/**
|
||||
* @brief Query memory info.
|
||||
* Return snapshot of free memory, and total allocatable memory on the device.
|
||||
|
||||
@@ -649,6 +649,14 @@ inline static hipError_t hipMemset2DAsync(void* dst, size_t pitch, int value, si
|
||||
return hipCUDAErrorTohipError(cudaMemset2DAsync(dst, pitch, value, width, height, stream));
|
||||
}
|
||||
|
||||
inline static hipError_t hipMemset3D(hipPitchedPtr pitchedDevPtr, int value, hipExtent extent ){
|
||||
return hipCUDAErrorTohipError(cudaMemset3D(pitchedDevPtr, value, extent));
|
||||
}
|
||||
|
||||
inline static hipError_t hipMemset3DAsync(hipPitchedPtr pitchedDevPtr, int value, hipExtent extent, hipStream_t stream __dparm(0) ){
|
||||
return hipCUDAErrorTohipError(cudaMemset3DAsync(pitchedDevPtr, value, extent, stream));
|
||||
}
|
||||
|
||||
inline static hipError_t hipGetDeviceProperties(hipDeviceProp_t* p_prop, int device) {
|
||||
struct cudaDeviceProp cdprop;
|
||||
cudaError_t cerror;
|
||||
|
||||
Yeni konuda referans
Bir kullanıcı engelle